@@ -88,50 +88,10 @@ class Core:
 
         return rec
 
-    def pipeline_from_record(self, record):
-        name = record["name"]
-        watchdog = record.get("watchdog", 0)
-        success_info = record.get("success_info", None)
-        workspace = record.get("workspace", None)
-
-        gitdata = None
-        if workspace is None:
-            workspace = tempfile.mkdtemp()
-
-        if "git" in record:
-            git = record["git"]
-            giturl = git["url"]
-            gitbranch = git.get("branch", "master")
-            gitcommit = git.get("commit", None)
-            gitname = git.get("name", None)
-            gitdata = {"url": giturl, "branch": gitbranch,
-                       "commit": gitcommit, "name": gitname}
-            #workspace = os.path.join(workspace, name)
-
-        if "use_template" in record:
-            template_name = record["use_template"]
-            template = self.find_pipeline_template(template_name)
-            subst = {}
-            for key in record["args"]:
-                subst[key] = record["args"][key]
-            return self.pipeline_from_record(
-                self.compile_pipeline_record(template=template,
-                                             subst=subst,
-                                             name=name))
-        else:
-            return Pipeline(
-                core=self,
-                name=name,
-                step_records=record["steps"],
-                watchdog=watchdog,
-                success_info=success_info,
-                workspace=workspace,
-                gitdata=gitdata)
-
     def parse_pipelines(self, list_of_pipeline_records):
         pipelines = []
         for pipeline_record in list_of_pipeline_records:
-            pipelines.append(self.pipeline_from_record(pipeline_record))
+            pipelines.append(Pipeline.from_record(pipeline_record, core=self))
         return pipelines
 
     def find_pipeline(self, name: str):
@@ -147,8 +107,9 @@ class Core:
         raise Exception("Pipeline template not found: " + name)
 
     def create_build_directory_and_change_it(self):
-        temporary_directory = tempfile.mkdtemp()
-        os.chdir(temporary_directory)
+        print("Create core workspace")
+        temporary_directory = self.executor.make_temporary_directory()
+        self.executor.chdir(temporary_directory)
         self.workspace = temporary_directory
 
     def execute_entrypoint(self, entrypoint: str):
@@ -164,7 +125,9 @@ class Core:
                                  prefix=self.prefix,
                                  subst={})
             except Exception as e:
+                current_directory = os.getcwd()
                 print("Exception: " + str(e))
+                print("Location: " + current_directory)
                 print("Traceback: " + traceback.format_exc())
                 self.on_failure(pipeline, matrix_value, e)
                 break
